pub struct GenerateIdTokenRequest {
pub audience: Option<String>,
pub delegates: Option<Vec<String>>,
pub include_email: Option<bool>,
pub organization_number_included: Option<bool>,
}Expand description
There is no detailed description.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
audience: Option<String>Required. The audience for the token, such as the API or account that this token grants access to.
delegates: Option<Vec<String>>The sequence of service accounts in a delegation chain. Each service account must be granted the roles/iam.serviceAccountTokenCreator role on its next service account in the chain. The last service account in the chain must be granted the roles/iam.serviceAccountTokenCreator role on the service account that is specified in the name field of the request. The delegates must have the following format: projects/-/serviceAccounts/{ACCOUNT_EMAIL_OR_UNIQUEID}. The - wildcard character is required; replacing it with a project ID is invalid.
include_email: Option<bool>Include the service account email in the token. If set to true, the token will contain email and email_verified claims.
organization_number_included: Option<bool>Include the organization number of the service account in the token. If set to true, the token will contain a google.organization_number claim. The value of the claim will be null if the service account isn’t associated with an organization.