pub struct ProjectMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on project resources.
It is not used directly, but through the IAMCredentials hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_iamcredentials1 as iamcredentials1;
use iamcredentials1::{IAMCredentials, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = IAMCredentials::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `locations_workload_identity_pools_get_allowed_locations(...)`, `service_accounts_generate_access_token(...)`, `service_accounts_generate_id_token(...)`, `service_accounts_get_allowed_locations(...)`, `service_accounts_sign_blob(...)` and `service_accounts_sign_jwt(...)`
// to build up your call.
let rb = hub.projects();Implementations
Sourceimpl<'a, C> ProjectMethods<'a, C>
impl<'a, C> ProjectMethods<'a, C>
Sourcepub fn locations_workload_identity_pools_get_allowed_locations(
&self,
name: &str,
) -> ProjectLocationWorkloadIdentityPoolGetAllowedLocationCall<'a, C>
pub fn locations_workload_identity_pools_get_allowed_locations( &self, name: &str, ) -> ProjectLocationWorkloadIdentityPoolGetAllowedLocationCall<'a, C>
Create a builder to help you perform the following task:
Returns the trust boundary info for a given workload identity pool.
Arguments
name- Required. Resource name of workload identity pool.
Sourcepub fn service_accounts_generate_access_token(
&self,
request: GenerateAccessTokenRequest,
name: &str,
) -> ProjectServiceAccountGenerateAccessTokenCall<'a, C>
pub fn service_accounts_generate_access_token( &self, request: GenerateAccessTokenRequest, name: &str, ) -> ProjectServiceAccountGenerateAccessTokenCall<'a, C>
Create a builder to help you perform the following task:
Generates an OAuth 2.0 access token for a service account.
Arguments
request- No description provided.name- Required. The resource name of the service account for which the credentials are requested, in the following format:projects/-/serviceAccounts/{ACCOUNT_EMAIL_OR_UNIQUEID}. The-wildcard character is required; replacing it with a project ID is invalid.
Sourcepub fn service_accounts_generate_id_token(
&self,
request: GenerateIdTokenRequest,
name: &str,
) -> ProjectServiceAccountGenerateIdTokenCall<'a, C>
pub fn service_accounts_generate_id_token( &self, request: GenerateIdTokenRequest, name: &str, ) -> ProjectServiceAccountGenerateIdTokenCall<'a, C>
Create a builder to help you perform the following task:
Generates an OpenID Connect ID token for a service account.
Arguments
request- No description provided.name- Required. The resource name of the service account for which the credentials are requested, in the following format:projects/-/serviceAccounts/{ACCOUNT_EMAIL_OR_UNIQUEID}. The-wildcard character is required; replacing it with a project ID is invalid.
Sourcepub fn service_accounts_get_allowed_locations(
&self,
name: &str,
) -> ProjectServiceAccountGetAllowedLocationCall<'a, C>
pub fn service_accounts_get_allowed_locations( &self, name: &str, ) -> ProjectServiceAccountGetAllowedLocationCall<'a, C>
Create a builder to help you perform the following task:
Returns the trust boundary info for a given service account.
Arguments
name- Required. Resource name of service account.
Sourcepub fn service_accounts_sign_blob(
&self,
request: SignBlobRequest,
name: &str,
) -> ProjectServiceAccountSignBlobCall<'a, C>
pub fn service_accounts_sign_blob( &self, request: SignBlobRequest, name: &str, ) -> ProjectServiceAccountSignBlobCall<'a, C>
Create a builder to help you perform the following task:
Signs a blob using a service account’s system-managed private key.
Arguments
request- No description provided.name- Required. The resource name of the service account for which the credentials are requested, in the following format:projects/-/serviceAccounts/{ACCOUNT_EMAIL_OR_UNIQUEID}. The-wildcard character is required; replacing it with a project ID is invalid.
Sourcepub fn service_accounts_sign_jwt(
&self,
request: SignJwtRequest,
name: &str,
) -> ProjectServiceAccountSignJwtCall<'a, C>
pub fn service_accounts_sign_jwt( &self, request: SignJwtRequest, name: &str, ) -> ProjectServiceAccountSignJwtCall<'a, C>
Create a builder to help you perform the following task:
Signs a JWT using a service account’s system-managed private key.
Arguments
request- No description provided.name- Required. The resource name of the service account for which the credentials are requested, in the following format:projects/-/serviceAccounts/{ACCOUNT_EMAIL_OR_UNIQUEID}. The-wildcard character is required; replacing it with a project ID is invalid.