pub struct ServiceAccountAllowedLocations {
pub encoded_locations: Option<String>,
pub locations: Option<Vec<String>>,
}Expand description
Represents a list of allowed locations for given service account.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
encoded_locations: Option<String>Output only. The hex encoded bitmap of the trust boundary locations
locations: Option<Vec<String>>Output only. The human readable trust boundary locations. For example, [“us-central1”, “europe-west1”]